@@ -15,7 +15,7 @@ fieldhash my %table      => 'table';
 fieldhash my %table_info => 'table_info';
 fieldhash my %type       => 'type';
 
-our $VERSION = '2.06';
+our $VERSION = '2.07';
 
 # -----------------------------------------------
 
@@ -112,19 +112,26 @@ sub get_table_info
 	for my $table_name (sort keys %table_data)
 	{
 		@foreign_info = ();
-		$sth          = $dbh -> foreign_key_info(undef, undef, undef, $self -> catalog, $self -> schema, $table_name);
 
-		if (defined $sth)
+		if ($vendor eq 'SQLITE')
 		{
+			for my $row (@{$dbh -> selectall_arrayref("pragma foreign_key_list($table_name)")})
+			{
+				push @foreign_info, [$$row[4], $$row[2], $$row[3] ];
+			}
+		}
+		else
+		{
+			$sth        = $dbh -> foreign_key_info(undef, undef, undef, $self -> catalog, $self -> schema, $table_name) || next;
 			$table_info = $sth -> fetchall_arrayref({});
 
 			for $column_data (@$table_info)
 			{
 				push @foreign_info, [$$column_data{'fk_column_name'}, $$column_data{'uk_table_name'}, $$column_data{'uk_column_name'}];
 			}
-
-			$table_data{$table_name}{foreign_keys} = [sort @foreign_info];
 		}
+
+		$table_data{$table_name}{foreign_keys} = [sort{$$a[1] cmp $$b[1]} @foreign_info];
 	}
 
 	$self -> table_info(\%table_data);
@@ -181,23 +188,23 @@ L<GraphViz2::DBI> - Visualize a database schema as a graph
 =head1 Synopsis
 
 	#!/usr/bin/env perl
-	
+
 	use strict;
 	use warnings;
-	
+
 	use DBI;
-	
+
 	use GraphViz2;
 	use GraphViz2::DBI;
-	
+
 	use Log::Handler;
-	
+
 	# ---------------
-	
+
 	exit 0 if (! $ENV{DBI_DSN});
-	
+
 	my($logger) = Log::Handler -> new;
-	
+
 	$logger -> add
 		(
 		 screen =>
@@ -207,7 +214,7 @@ L<GraphViz2::DBI> - Visualize a database schema as a graph
 			 minlevel       => 'error',
 		 }
 		);
-	
+
 	my($graph) = GraphViz2 -> new
 		(
 		 edge   => {color => 'grey'},
@@ -216,14 +223,19 @@ L<GraphViz2::DBI> - Visualize a database schema as a graph
 		 logger => $logger,
 		 node   => {color => 'blue', shape => 'oval'},
 		);
-	my($dbh) = DBI -> connect($ENV{DBI_DSN}, $ENV{DBI_USER}, $ENV{DBI_PASS});
-	my($g)   = GraphViz2::DBI -> new(dbh => $dbh, graph => $graph);
-	
-	$g -> create(name => 'App-Office-CMS');
-	
+	my($attr)              = {};
+	$$attr{sqlite_unicode} = 1 if ($ENV{DBI_DSN} =~ /SQLite/i);
+	my($dbh)               = DBI -> connect($ENV{DBI_DSN}, $ENV{DBI_USER}, $ENV{DBI_PASS}, $attr);
+
+	$dbh -> do('PRAGMA foreign_keys = ON') if ($ENV{DBI_DSN} =~ /SQLite/i);
+
+	my($g) = GraphViz2::DBI -> new(dbh => $dbh, graph => $graph);
+
+	$g -> create(name => '');
+
 	my($format)      = shift || 'svg';
 	my($output_file) = shift || File::Spec -> catfile('html', "dbi.schema.$format");
-	
+
 	$graph -> run(format => $format, output_file => $output_file);
 
 See scripts/dbi.schema.pl (L<GraphViz2/Scripts Shipped with this Module>).
@@ -314,7 +326,26 @@ Returns the graph object, either the one supplied to new() or the one created du
 
 =head1 FAQ
 
-See L<GraphViz2/FAQ> and L<GraphViz2/Scripts Shipped with this Module>.
+=head2 Does GraphViz2::DBI work with SQLite databases?
+
+Yes. As of V 2.07, this module uses SQLite's "pragma foreign_key_list($table_name)" to emulate L<DBI>'s
+$dbh -> foreign_key_info(...).
+
+=head2 What is returned by SQLite's "pragma foreign_key_list($table_name)"?
+
+	Fields returned are:
+	0: COUNT   (0, 1, ...)
+	1: KEY_SEQ (0, or column # (1, 2, ...) within multi-column key)
+	2: FKTABLE_NAME
+	3: PKCOLUMN_NAME
+	4: FKCOLUMN_NAME
+	5: UPDATE_RULE
+	6: DELETE_RULE
+	7: 'NONE' (Constant string)
+
+=head2 Are any sample scripts shipped with this module?
+
+Yes. See L<GraphViz2/FAQ> and L<GraphViz2/Scripts Shipped with this Module>.
 
 =head1 Thanks
 
